"use client";
import React from 'react';
import { FaMapMarkerAlt, FaBuilding, FaRuler } from 'react-icons/fa';

const AdminPostPage = () => {
  const property = {
    price: "₹ 65,00,586 L Per SQ Feet",
    title: "Residential Land / Plot in Sarvhit Apartments",
    landSize: "2500 sqyrd",
    landType: "Residential",
    dimensions: "10.55*23*8",
    location: "Land sell in Indirapuram, Abhay Khand 3, Near Sai Mandir",
    developerName: "Suraj Pandey",
    image: "/buyland.png"
  };

  const renderPropertyDetails = (property) => (
    <div className="flex flex-col gap-2">
      <div className="text-xl font-bold">{property.price}</div>
      <h2 className="text-lg font-semibold">{property.title}</h2>
      <p className="text-gray-600 text-sm">Posted by Admin</p>
      <div className="bg-gray-100 p-2 rounded-lg grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-2">
        <div className="flex items-center gap-2">
          <FaMapMarkerAlt className="text-gray-600" />
          <div>
            <p className="text-xs">Land Size</p>
            <p className="font-semibold text-sm">{property.landSize}</p>
          </div>
        </div>
        <div className="flex items-center gap-2">
          <FaBuilding className="text-gray-600" />
          <div>
            <p className="text-xs">Land Type</p>
            <p className="font-semibold text-sm">{property.landType}</p> 
          </div>
        </div>
        <div className="flex items-center gap-2">
          <FaRuler className="text-gray-600" />
          <div>
            <p className="text-xs">Dimension (L*B)</p>
            <p className="font-semibold text-sm">{property.dimensions}</p>
          </div>
        </div>
      </div>
      <div className="flex flex-col sm:flex-row gap-2 text-xs">
        <p className="font-semibold text-blue-600 underline">{property.location}</p>
        <div className="flex items-center gap-1 text-red-500 cursor-pointer hover:underline">
          <FaMapMarkerAlt />
          <span>View Map</span>
        </div>
      </div>
      <div className="flex flex-col sm:flex-row items-center justify-between mt-2">
        <div className="flex items-center gap-2 mb-2 sm:mb-0">
          <img src="/profile.png" alt="Developer" className="w-10 h-10 rounded-full" />
          <span className="font-semibold">{property.developerName}</span>
        </div>
        <div className="flex gap-2">
          <button className="bg-white text-purple-600 border border-purple-600 px-4 py-2 rounded-lg text-sm hover:bg-purple-100 transition-colors duration-300">
            Know More
          </button>
          <button className="bg-purple-600 text-white px-4 py-2 rounded-lg text-sm hover:bg-purple-700 transition-colors duration-300">
            Contact Seller
          </button>
        </div>
      </div>
    </div>
  );

  return (
    <div className="font-sans w-full">
      <div className="w-full">
        <div className="bg-white rounded-lg shadow-lg overflow-hidden">
          <div className="flex flex-col lg:flex-row">
            <img
              src={property.image}
              alt="Property"
              className="w-full lg:w-1/2 h-48 lg:h-64 object-cover"
            />
            <div className="w-full lg:w-1/2 p-4">
              {renderPropertyDetails(property)}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AdminPostPage; 